@@ -7,16 +7,15 @@ if (system.args.length < 3) {
     phantom.exit(1);
 } else {
     var content = '',
-        f = null;
+        f = null,
+        i;
     for ( i= 2; i < system.args.length; ++i ) {
         content += system.args[i] + (i === system.args.length-1 ? '' : ' ');
     }
     
     try {
-        f = fs.open(system.args[1], "w");
-        f.writeLine(content);
-        f.close();
-    } catch (e) {
+        fs.write(system.args[1], content, 'w');
+    } catch(e) {
         console.log(e);
     }
 
